==> huaweicloudsdkcodeartsdeploy-3.1.75-py2.py3-none-any.whl: huaweicloudsdkcodeartsdeploy/v2/model/task_v2_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class TaskV2RequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'template_id': 'str',
        'operation_list': 'list[DeployV2OperationsDO]'
    }

    attribute_map = {
        'template_id': 'template_id',
        'operation_list': 'operation_list'
    }

    def __init__(self, template_id=None, operation_list=None):
        """TaskV2RequestBody

        The model defined in huaweicloud sdk

        :param template_id: 模板id
        :type template_id: str
        :param operation_list: 部署编排列表信息
        :type operation_list: list[:class:`huaweicloudsdkcodeartsdeploy.v2.DeployV2OperationsDO`]
        """
        
        

        self._template_id = None
        self._operation_list = None
        self.discriminator = None

        if template_id is not None:
            self.template_id = template_id
        if operation_list is not None:
            self.operation_list = operation_list

    @property
    def template_id(self):
        """Gets the template_id of this TaskV2RequestBody.

        模板id

        :return: The template_id of this TaskV2RequestBody.
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this TaskV2RequestBody.

        模板id

        :param template_id: The template_id of this TaskV2RequestBody.
        :type template_id: str
        """
        self._template_id = template_id

    @property
    def operation_list(self):
        """Gets the operation_list of this TaskV2RequestBody.

        部署编排列表信息

        :return: The operation_list of this TaskV2RequestBody.
        :rtype: list[:class:`huaweicloudsdkcodeartsdeploy.v2.DeployV2OperationsDO`]
        """
        return self._operation_list

    @operation_list.setter
    def operation_list(self, operation_list):
        """Sets the operation_list of this TaskV2RequestBody.

        部署编排列表信息

        :param operation_list: The operation_list of this TaskV2RequestBody.
        :type operation_list: list[:class:`huaweicloudsdkcodeartsdeploy.v2.DeployV2OperationsDO`]
        """
        self._operation_list = operation_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaskV2RequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcodeartsdeploy-3.1.150-py2.py3-none-any.whl: huaweicloudsdkcodeartsdeploy/v2/model/task_v2_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class TaskV2RequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'template_id': 'str',
        'operation_list': 'list[DeployV2OperationsDO]'
    }

    attribute_map = {
        'template_id': 'template_id',
        'operation_list': 'operation_list'
    }

    def __init__(self, template_id=None, operation_list=None):
        r"""TaskV2RequestBody

        The model defined in huaweicloud sdk

        :param template_id: 模板id
        :type template_id: str
        :param operation_list: 部署编排列表信息
        :type operation_list: list[:class:`huaweicloudsdkcodeartsdeploy.v2.DeployV2OperationsDO`]
        """
        
        

        self._template_id = None
        self._operation_list = None
        self.discriminator = None

        if template_id is not None:
            self.template_id = template_id
        if operation_list is not None:
            self.operation_list = operation_list

    @property
    def template_id(self):
        r"""Gets the template_id of this TaskV2RequestBody.

        模板id

        :return: The template_id of this TaskV2RequestBody.
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        r"""Sets the template_id of this TaskV2RequestBody.

        模板id

        :param template_id: The template_id of this TaskV2RequestBody.
        :type template_id: str
        """
        self._template_id = template_id

    @property
    def operation_list(self):
        r"""Gets the operation_list of this TaskV2RequestBody.

        部署编排列表信息

        :return: The operation_list of this TaskV2RequestBody.
        :rtype: list[:class:`huaweicloudsdkcodeartsdeploy.v2.DeployV2OperationsDO`]
        """
        return self._operation_list

    @operation_list.setter
    def operation_list(self, operation_list):
        r"""Sets the operation_list of this TaskV2RequestBody.

        部署编排列表信息

        :param operation_list: The operation_list of this TaskV2RequestBody.
        :type operation_list: list[:class:`huaweicloudsdkcodeartsdeploy.v2.DeployV2OperationsDO`]
        """
        self._operation_list = operation_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaskV2RequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
